@@ -58,10 +58,6 @@ def encode_value(v):
     """If the value contains a semicolon, or starts with a left curly brace,
     then enclose it in curly braces and escape all right curly braces.
     """
-    print('v-> ', v)
-    if type(v) is dict:
-        print('worked----')
-        return v
     if ';' in v or v.strip(' ').startswith('{'):
         return '{%s}' % (v.replace('}', '}}'),)
     return v
@@ -291,7 +287,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
                 exp_token += bytes({i})
                 exp_token += bytes(1)
             token_struct = struct.pack("=i", len(exp_token)) + exp_token
-            # cstr_parts['attrs_before'] = {1256: bytearray(token_struct)}
+            cstr_parts['attrs_before'] = {1256: bytearray(token_struct)}
         elif user:
             cstr_parts['UID'] = user
             cstr_parts['PWD'] = password
@@ -305,19 +301,15 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 
         if ms_drivers.match(driver) and os.name == 'nt':
             cstr_parts['MARS_Connection'] = 'yes'
-        #print('cstr_parts--> ', cstr_parts)
+
         connstr = encode_connection_string(cstr_parts)
+
         # extra_params are glued on the end of the string without encoding,
         # so it's up to the settings writer to make sure they're appropriate -
         # use encode_connection_string if constructing from external input.
-        # if options.get('extra_params', None):
-        #     connstr += ';' + options['extra_params']
-        print('connection String--> ', connstr)
-        # import re
-        # connstr = re.sub('attrs_before.*?};', '', connstr)
-        # print('after connection String--> ', connstr)
-        cstr_parts['attrs_before'] = {1256: bytearray(token_struct)}
-        print('atts_before Key: ',cstr_parts['attrs_before'])
+        if options.get('extra_params', None):
+            connstr += ';' + options['extra_params']
+
         unicode_results = options.get('unicode_results', False)
         timeout = options.get('connection_timeout', 0)
         retries = options.get('connection_retries', 5)
@@ -329,13 +321,10 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         need_to_retry = False
         while conn is None:
             try:
-                print('retry count: ', retry_count)
                 conn = Database.connect(connstr,
-                                        attrs_before=cstr_parts['attrs_before'],
                                         unicode_results=unicode_results,
                                         timeout=timeout)
             except Exception as e:
-                print('Error occurred during connect: ', e)
                 for error_number in self._transient_error_numbers:
                     if error_number in e.args[1]:
                         if error_number in e.args[1] and retry_count < retries:
